/*
 * Copyright (c) 2001, DecisionSoft Limited All rights reserved.
 * Please see LICENSE.TXT for more information.
 */

#include <xercesc/dom/DOM.hpp>
#include <xercesc/parsers/XercesDOMParser.hpp>
#include <xercesc/util/PlatformUtils.hpp>
#include <interface/XPathNSResolverImpl.hpp>
#include <interface/XPathResultImpl.hpp>
#include <interface/XPathEvaluatorImpl.hpp>
#include <DOMutils/XStr.hpp>
#include "DOMSerialise.hpp"

#include <iostream>

using namespace std;

int main()
{
	// Initialize the XML4C2 system

	try {
    XERCES_CPP_NAMESPACE_QUALIFIER XMLPlatformUtils::Initialize();
  }
	catch(const XERCES_CPP_NAMESPACE_QUALIFIER XMLException& toCatch) {
		cerr << "Error during Xerces-c Initialization.\n"
                     << "  Exception message:"
                     << XERCES_CPP_NAMESPACE_QUALIFIER XMLString::transcode(toCatch.getMessage()) << endl;
		return 1;
	}

	XERCES_CPP_NAMESPACE_QUALIFIER XercesDOMParser *xmlParser = new XERCES_CPP_NAMESPACE_QUALIFIER XercesDOMParser();

	xmlParser->setDoNamespaces(true);
	xmlParser->parse("data.xml");

	const XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument *testDoc = xmlParser->getDocument();
	XERCES_CPP_NAMESPACE_QUALIFIER DOMNode *tmpNode = testDoc->getDocumentElement();

	try {
    XPathEvaluator *evaluator = new XPathEvaluatorImpl();
		XPathResult *tmpResult;

		XPathNSResolver *docNSResolver = evaluator->createNSResolver(tmpNode);

		//First <spork/> element
		XPathExpression *parsedExpression = evaluator->createExpression(X("/child::*[1]/child::*[1]/child::*[1]"), docNSResolver);
		tmpResult = parsedExpression->evaluate(tmpNode, XPathResult::FIRST_ORDERED_NODE_TYPE, tmpResult);

		XERCES_CPP_NAMESPACE_QUALIFIER DOMNode *spork = tmpResult->getSingleNodeValue();

		//Then we want to set it as the trigger and get its namespaces
		docNSResolver = evaluator->createNSResolver(spork);

		parsedExpression = evaluator->createExpression(X("namespace::*"), docNSResolver);

		tmpResult = parsedExpression->evaluate(spork, XPathResult::ORDERED_NODE_SNAPSHOT_TYPE, tmpResult);

		//Now look at the namespace nodes:
		//There should be five namespace nodes
		int total = tmpResult->getSnapshotLength();
		cout << "Total number of namespace nodes is: " << total << "." << endl << endl;
		cout << "They are: " << endl;


		for(int cnt=0; cnt<total; cnt++) {
			XERCES_CPP_NAMESPACE_QUALIFIER DOMNode *tmpNode = tmpResult->snapshotItem(cnt);
			cout << tmpNode << endl;
		}//for
	}
	catch(const XPathException &e) {
		cout << "XPathException: " << e.getString() << endl;
		return 1;
	}
	catch(const XERCES_CPP_NAMESPACE_QUALIFIER DOMException &e) {
		cout << "XERCES_CPP_NAMESPACE_QUALIFIER DOMException " << e.code << " occured: " << e.msg << endl;
		return 1;
	}

	return 0;
}//main


