/*
 * Copyright (c) 2001, DecisionSoft Limited All rights reserved.
 * Please see LICENSE.TXT for more information.
 */

#include <iostream>

#include <xercesc/dom/DOM.hpp>
#include <xercesc/parsers/XercesDOMParser.hpp>
#include <xercesc/util/PlatformUtils.hpp>
#include <interface/XPathNSResolverImpl.hpp>
#include <interface/XPathResultImpl.hpp>
#include <interface/XPathEvaluatorImpl.hpp>
#include "DOMSerialise.hpp"
#include <DOMutils/XStr.hpp>

using namespace std;

int main()
{

	// Initialize the XML4C2 system

	try {
		XERCES_CPP_NAMESPACE_QUALIFIER XMLPlatformUtils::Initialize();
	}

	catch(const XERCES_CPP_NAMESPACE_QUALIFIER XMLException& toCatch) {
		cerr << "Error during Xerces-c Initialization.\n"
		     << "  Exception message:"
		     << XERCES_CPP_NAMESPACE_QUALIFIER XMLString::transcode(toCatch.getMessage()) << endl;
		return 1;
	}


	XERCES_CPP_NAMESPACE_QUALIFIER XercesDOMParser *xmlParser = new XERCES_CPP_NAMESPACE_QUALIFIER XercesDOMParser();

	xmlParser->setDoNamespaces(true);
	xmlParser->parse("data.xml");

	const XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument *testDoc = xmlParser->getDocument();

	XERCES_CPP_NAMESPACE_QUALIFIER DOMNode *tmpNode = testDoc->getDocumentElement();

	try {
    XPathEvaluator *evaluator = new XPathEvaluatorImpl();
		XPathResult *snapshotResult, *iteratorResult;

		XPathNSResolver *docNSResolver = evaluator->createNSResolver(tmpNode);

		//Find <data> children
		XPathExpression *parsedExpression = evaluator->createExpression(X("/child::*[1]/*"), docNSResolver);

		//Get Snapshot and Iterator type result
		snapshotResult = parsedExpression->evaluate(tmpNode, XPathResult::ORDERED_NODE_SNAPSHOT_TYPE, snapshotResult);
		iteratorResult = parsedExpression->evaluate(tmpNode, XPathResult::ORDERED_NODE_ITERATOR_TYPE, iteratorResult);

		//Go through the types, comparing their entries
		int totalCount = snapshotResult->getSnapshotLength();
		cout << "Total nodes in set is " << totalCount << endl;

		for(int cnt=0; cnt<totalCount; cnt++) {
			XERCES_CPP_NAMESPACE_QUALIFIER DOMNode *nodeA = iteratorResult->iterateNext();
			XERCES_CPP_NAMESPACE_QUALIFIER DOMNode *nodeB = snapshotResult->snapshotItem(cnt);

			cout << "Node " << cnt << ": " << nodeA << " - ";
			if(nodeA != nodeB) {
				cout << "Nodes are not equal. (" << nodeB << ")" << endl;
			} else {
				cout << "Nodes are equal." << endl;
			}//if
		}//for

		//Now, if we try to get the next node on each, it should fail
		XERCES_CPP_NAMESPACE_QUALIFIER DOMNode *tmpNode1 = iteratorResult->iterateNext();
		XERCES_CPP_NAMESPACE_QUALIFIER DOMNode *tmpNode2 = snapshotResult->snapshotItem(totalCount+1);

		if((tmpNode1 != tmpNode2) || (tmpNode1!=NULL)) {
			cout << "Some strange node returned: ";

			if(tmpNode1!=NULL) {
				cout << tmpNode1;
			} else {
				cout << "null";
			}//if

			cout << "(";
			if(tmpNode2!=NULL) {
				cout << tmpNode2;
			} else {
				cout << "null";
			}//if

			cout << ")" << endl;
		} else {
			cout << "Null nodes returned." << endl;
		}//if


		//And again
		tmpNode1 = iteratorResult->iterateNext();
		tmpNode2 = snapshotResult->snapshotItem(totalCount+2);

		if((tmpNode1 != tmpNode2) || (tmpNode1!=NULL)) {
			cout << "Some strange node returned: ";

			if(tmpNode1!=NULL) {
				cout << tmpNode1;
			} else {
				cout << "null";
			}//if

			cout << "(";
			if(tmpNode2!=NULL) {
				cout << tmpNode2;
			} else {
				cout << "null";
			}//if

			cout << ")" << endl;
		} else {
			cout << "Null nodes returned." << endl;
		}//if
	}
	catch(const XPathException &e) {
		cout << "XPathException: " << e.getString() << endl;
		return 1;
	}
	catch(const XERCES_CPP_NAMESPACE_QUALIFIER DOMException &e) {
		cout << "XERCES_CPP_NAMESPACE_QUALIFIER DOMException " << e.code << " occured: " << e.msg << endl;
		return 1;
	}

	return 0;
}//main

