/*
 * Copyright (c) 2001, DecisionSoft Limited All rights reserved.
 * Please see LICENSE.TXT for more information.
 */

#include <iostream>

#include <xercesc/dom/DOM.hpp>
#include <xercesc/parsers/XercesDOMParser.hpp>
#include <xercesc/util/PlatformUtils.hpp>
#include <interface/XPathNSResolverImpl.hpp>
#include <interface/XPathResultImpl.hpp>
#include <interface/XPathEvaluatorImpl.hpp>
#include <DOMutils/XStr.hpp>
#include "DOMSerialise.hpp"

using namespace std;

int main()
{

	// Initialize the XML4C2 system
	try {
		XERCES_CPP_NAMESPACE_QUALIFIER XMLPlatformUtils::Initialize();
	}

	catch(const XERCES_CPP_NAMESPACE_QUALIFIER XMLException& toCatch) {
		cerr << "Error during Xerces-c Initialization.\n"
		     << "  Exception message:"
		     << XERCES_CPP_NAMESPACE_QUALIFIER XMLString::transcode(toCatch.getMessage()) << endl;
		return 1;
	}

  XERCES_CPP_NAMESPACE_QUALIFIER XercesDOMParser *xmlParser = new XERCES_CPP_NAMESPACE_QUALIFIER XercesDOMParser();
  
	xmlParser->setDoNamespaces(true);
	xmlParser->parse("data.xml");

	const XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument *testDoc = xmlParser->getDocument();

	XERCES_CPP_NAMESPACE_QUALIFIER DOMNode *tmpNode = testDoc->getDocumentElement();

  XPathEvaluator *evaluator = new XPathEvaluatorImpl();
  XPathResult *tmpResult;
  XPathNSResolver *docNSResolver = evaluator->createNSResolver(tmpNode);
  XPathExpression *parsedExpression;

  try {

		//Find children of <data>
		parsedExpression = evaluator->createExpression(X("/child::*[1]/*"), docNSResolver);
		tmpResult = parsedExpression->evaluate(tmpNode, XPathResult::ORDERED_NODE_SNAPSHOT_TYPE, tmpResult);
	}
	catch(const XPathException &e) {
		cout << "XPathException: " << e.getString() << endl;
		return 1;
	}
	catch(const XERCES_CPP_NAMESPACE_QUALIFIER DOMException &e) {
		cout << "XERCES_CPP_NAMESPACE_QUALIFIER DOMException " << e.code << " occured: " << e.msg << endl;
		return 1;
	}

	//Bad result tests

	try {
		double tmpVal;
		tmpVal = tmpResult->getNumberValue();
	}
	catch(const XPathException &e) {
		cout << "XPathException: " << e.getString() << endl;
	}

	try {
		const XMLCh *tmpVal = tmpResult->getStringValue();
	}
	catch(const XPathException &e) {
		cout << "XPathException: " << e.getString() << endl;
	}

	try {
		bool tmpVal;
		tmpVal = tmpResult->getBooleanValue();
	}
	catch(const XPathException &e) {
		cout << "XPathException: " << e.getString() << endl;
	}

	try {
		XERCES_CPP_NAMESPACE_QUALIFIER DOMNode *tmpVal = tmpResult->getSingleNodeValue();
	}
	catch(const XPathException &e) {
		cout << "XPathException: " << e.getString() << endl;
	}

	try {
		XERCES_CPP_NAMESPACE_QUALIFIER DOMNode *tmpVal = tmpResult->iterateNext();
	}
	catch(const XPathException &e) {
		cout << "XPathException: " << e.getString() << endl;
	}

	//More bad cases for snapshot methods

	try {
		docNSResolver = evaluator->createNSResolver(tmpNode);

		//Find children of <data>
		parsedExpression = evaluator->createExpression(X("/child::*[1]/*"), docNSResolver);
		tmpResult = parsedExpression->evaluate(tmpNode, XPathResult::UNORDERED_NODE_ITERATOR_TYPE, tmpResult);
	}
	catch(const XPathException &e) {
		cout << "XPathException: " << e.getString() << endl;
		return 1;
	}
	catch(const XERCES_CPP_NAMESPACE_QUALIFIER DOMException &e) {
		cout << "XERCES_CPP_NAMESPACE_QUALIFIER DOMException " << e.code << " occured: " << e.msg << endl;
		return 1;
	}

	try {
		unsigned long tmpVal;
		tmpVal = tmpResult->getSnapshotLength();
	}
	catch(const XPathException &e) {
		cout << "XPathException: " << e.getString() << endl;
	}

	try {
		XERCES_CPP_NAMESPACE_QUALIFIER DOMNode *tmpVal = tmpResult->snapshotItem(0);
	}
	catch(const XPathException &e) {
		cout << "XPathException: " << e.getString() << endl;
	}


	return 0;
}//main

