/*
 * Copyright (c) 2001, DecisionSoft Limited All rights reserved.
 * Please see LICENSE.TXT for more information.
 */

#include <iostream>

#include <xercesc/dom/DOM.hpp>
#include <xercesc/parsers/XercesDOMParser.hpp>
#include <xercesc/util/PlatformUtils.hpp>
#include <interface/XPathNSResolverImpl.hpp>
#include <interface/XPathResultImpl.hpp>
#include <interface/XPathEvaluatorImpl.hpp>
#include <DOMutils/XStr.hpp>
#include <dom3-xpath/Pathan.hpp>
#include "DOMSerialise.hpp"

using namespace std;

int main()
{
        
	// Initialize the XML4C2 system
    
	try
	{
		XERCES_CPP_NAMESPACE_QUALIFIER XMLPlatformUtils::Initialize();
	}

	catch(const XERCES_CPP_NAMESPACE_QUALIFIER XMLException& toCatch) {
		cerr << "Error during Xerces-c Initialization.\n"
			<< "  Exception message:"
			<< XERCES_CPP_NAMESPACE_QUALIFIER XMLString::transcode(toCatch.getMessage()) << endl;
		return 1;
	}

	Pathan::useWholeText(true);
	
  XERCES_CPP_NAMESPACE_QUALIFIER XercesDOMParser *xmlParser = new XERCES_CPP_NAMESPACE_QUALIFIER XercesDOMParser();

	xmlParser->setDoNamespaces(true);
	xmlParser->parse("data.xml");

	const XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument *testDoc = xmlParser->getDocument();

	XERCES_CPP_NAMESPACE_QUALIFIER DOMNode *tmpNode = testDoc->getDocumentElement();
	
  XPathEvaluator *evaluator = new XPathEvaluatorImpl();
  
	//Get all the text nodes of the textTest element
	XPathResult *tmpResult;

	XPathNSResolver *docNSResolver = evaluator->createNSResolver(tmpNode);

	XPathExpression *parsedExpression = evaluator->createExpression(X("/child::*[1]/textTest/text()"), docNSResolver);

	try {
		tmpResult = parsedExpression->evaluate(tmpNode, XPathResult::ORDERED_NODE_SNAPSHOT_TYPE, tmpResult);
	}
	catch(const XPathException &e) {
		cout << "XPathException: " << e.getString() << endl;
		return 0;
	}

	//There should be four namespace nodes
	int total = tmpResult->getSnapshotLength();
	cout << "Total number of text nodes is: " << total << "." << endl << endl;
	cout << "They are: " << endl;
	
	
	for(int cnt=0; cnt<total; cnt++) {
		XERCES_CPP_NAMESPACE_QUALIFIER DOMNode *tmpNode = tmpResult->snapshotItem(cnt);

		cout << cnt << ": " << tmpNode->getNodeValue() << endl;
	}//for
	cout << endl << endl;

	//Now do some simple cases
	//Select non-existant text node
	parsedExpression = evaluator->createExpression(X("/child::*[1]/textTest/text()[50]"), docNSResolver);
	
	try {
		tmpResult = parsedExpression->evaluate(tmpNode, XPathResult::ORDERED_NODE_SNAPSHOT_TYPE, tmpResult);
	}
	catch(const XPathException &e) {
		cout << "XPathException: " << e.getString() << endl;
		return 0;
	}

	total = tmpResult->getSnapshotLength();
	cout << "Total number of text nodes is: " << total << "." << endl << endl;

	//Select specific node
	cout << endl;
	parsedExpression = evaluator->createExpression(X("/child::*[1]/textTest/text()[2]"), docNSResolver);
	
	try {
		tmpResult = parsedExpression->evaluate(tmpNode, XPathResult::ORDERED_NODE_SNAPSHOT_TYPE, tmpResult);
	}
	catch(const XPathException &e) {
		cout << "XPathException: " << e.getString() << endl;
		return 0;
	}

	total = tmpResult->getSnapshotLength();
	tmpNode = tmpResult->snapshotItem(0);
	cout << "Total number of text nodes is: " << total << ": '" 
			<<  XERCES_CPP_NAMESPACE_QUALIFIER XMLString::transcode(tmpNode->getNodeValue()) << "'." << endl << endl;

	return 0;
}//main

